@@ -9,8 +9,6 @@ test_that("varImp functions", {
     control = cforest_unbiased(mtry = 2, ntree = 50))
   varImp(object = readingSkills.cf, measure = "MSE")
   
-  iris.cf = cforest(Species ~ ., data = iris,control = cforest_unbiased(mtry = 2, ntree = 50))
-  varImpAUC(object = iris.cf, method = "ovo")
   # Erweitern auf beliebige Maße?
   
   # binary case
@@ -18,27 +16,31 @@ test_that("varImp functions", {
   iris2$Species = factor(iris$Species == "versicolor")
   iris.cf = cforest(Species ~ ., data = iris2,control = cforest_unbiased(mtry = 2, ntree = 50))
   set.seed(123)
-  a = varImpAUC(object = iris.cf, method = "ova")
-  set.seed(123)
-  b = varImpAUC(object = iris.cf, method = "ovo")
-  set.seed(123)
-  # c = varimpAUC(object = iris.cf) # current party implementation is wrong!
-  expect_equal(a,b)
+  a = varImpAUC(object = iris.cf)
+  expect_true(all(!is.na(a)))
+
   # expect_equal(b,c)
   d = varImp(object = iris.cf, measure = "Brier", positive = "FALSE")
   e = varImp(object = iris.cf, measure = "ACC")
   f = varImp(object = iris.cf, measure = "MMCE")
+  expect_true(all(!is.na(d)))
+  expect_true(all(!is.na(e)))
+  expect_true(all(!is.na(f)))
   
   # multiclass case
   iris.cf = cforest(Species ~ ., data = iris, control = cforest_unbiased(mtry = 2, ntree = 50))
   set.seed(123)
-  a = varImpAUC(object = iris.cf, method = "ovo")
+  a = varImp(object = iris.cf, measure = "multiclass.AU1P")
   set.seed(123)
-  b = varImpAUC(object = iris.cf, method = "ova")
-  set.seed(123)
-  c = varImpACC(object = iris.cf)
+  b = varImpACC(object = iris.cf)
   
   expect_true(all(!is.na(a)))
   expect_true(all(!is.na(b)))
-  expect_true(all(!is.na(c)))
+
+  # ranger
+  library(ranger)
+  iris.rg = ranger(Species ~ ., data = iris, keep.inbag = TRUE, probability = TRUE)
+  vimp.ranger = varImpRanger(object = iris.rg, data = iris, target = "Species")
+  expect_true(is.numeric(vimp.ranger))
+  expect_true(all(!is.na(vimp.ranger)))
 })
